@@ -1,10 +1,12 @@
 """exceptions.py"""
 
-class RPCClientException(Exception):
+
+class JsonRpcClientError(Exception):
     """Base class for the other rpcclient exceptions"""
     pass
 
-class ConnectionError(RPCClientException): # pylint: disable=redefined-builtin
+
+class ConnectionError(JsonRpcClientError): # pylint: disable=redefined-builtin
     """The requests module raised an error, which could be a network issue,
     invalid HTTP response or timeout. See
     http://stackoverflow.com/questions/16511337/"""
@@ -12,31 +14,50 @@ class ConnectionError(RPCClientException): # pylint: disable=redefined-builtin
     def __init__(self):
         super().__init__('Connection error')
 
-class StatusCodeError(RPCClientException):
+
+class InvalidRequest(JsonRpcClientError):
+    """The request you've sent is not valid json"""
+
+    def __init__(self):
+        super().__init__('The request you\'re sending is not valid json')
+
+
+class Non200Response(JsonRpcClientError):
     """The server responded with status code != 200"""
 
     def __init__(self, status_code):
         super().__init__('Returned status code '+str(status_code))
 
-class ParseError(RPCClientException):
+
+class ParseResponseError(JsonRpcClientError):
     """Couldnt parse the json response (invalid json)"""
 
     def __init__(self):
-        super().__init__('Parse error')
+        super().__init__('The response was not valid json')
 
-class InvalidResponse(RPCClientException):
-    """The response didnt validate against the JSON-RPC response schema"""
+
+class InvalidResponse(JsonRpcClientError):
+    """The response didnt validate against the json-rpc response schema"""
 
     def __init__(self):
-        super().__init__('Invalid response')
+        super().__init__('The response was not a valid json-rpc 2.0 response')
 
-class ReceivedNoResponse(RPCClientException):
+
+class UnwantedResponse(JsonRpcClientError):
+    """The response didnt validate against the json-rpc response schema"""
+
+    def __init__(self):
+        super().__init__('The response was not asked for')
+
+
+class ReceivedNoResponse(JsonRpcClientError):
     """A response was expected, but no response was received"""
 
     def __init__(self):
-        super().__init__('No response')
+        super().__init__('No response was received')
 
-class ReceivedErrorResponse(RPCClientException):
+
+class ReceivedErrorResponse(JsonRpcClientError):
     """The server responded with 'error'. Raise it so it must be handled"""
 
     def __init__(self, code, message): #pylint:disable=unused-argument
